%define anolis_release 1

Name:           lxc
Version:        5.0.2
Release:        %{anolis_release}%{?dist}
Summary:        Linux Resource Containers
License:        LGPLv2+ and GPLv2
URL:            https://linuxcontainers.org/lxc
Source0:        https://linuxcontainers.org/downloads/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  make meson
BuildRequires:  doxygen docbook2X
BuildRequires:  libselinux-devel systemd-devel libcap-devel pam-devel openssl-devel
BuildRequires:  pkgconfig(libseccomp) pkgconfig(bash-completion)
BuildRequires:  autoconf automake libtool libtool docbook-utils
Provides:       lxc-extra = %{version}-%{release}
Obsoletes:      lxc-extra < 1.1.5

%description
Linux Resource Containers provide process and resource isolation without the
overhead of full virtualization.


%package           libs
Summary:           Runtime library files for %{name}
Requires:          rsync
Requires(post):    systemd
Requires(preun):   systemd
Requires(postun):  systemd

%description    libs
Linux Resource Containers provide process and resource isolation without the
overhead of full virtualization.

The %{name}-libs package contains libraries for running %{name} applications.


%package        templates
Summary:        Templates for %{name}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       wget


%description    templates
Linux Resource Containers provide process and resource isolation without the
overhead of full virtualization.

The %{name}-templates package contains templates for creating containers.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       pkgconfig

%description    devel
Linux Resource Containers provide process and resource isolation without the
overhead of full virtualization.

The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        doc
Summary:        Documentation for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
This package contains documentation for %{name}.


%prep
%autosetup -p1 -n %{name}-%{version}


%build
%meson \
	-D examples=false \
	-D tests=false \
	-D init-script=systemd \
	-D systemd-unitdir=%{_unitdir} \
	-D distrosysconfdir=sysconfig \
	-D pam-cgroup=true \
	-D runtime-path=%{_rundir} \
	%{nil}
%meson_build

%install
%meson_install
rm -f %{buildroot}%{_libdir}/liblxc.a

%generate_compatibility_deps

%post libs
%systemd_post %{name}-net.service
%systemd_post %{name}.service
%systemd_post %{name}-monitord.service


%preun libs
%systemd_preun %{name}-net.service
%systemd_preun %{name}.service
%systemd_preun %{name}-monitord.service


%postun libs
%systemd_postun %{name}-net.service
%systemd_postun %{name}.service
%systemd_postun %{name}-monitord.service


%files
%{_bindir}/%{name}-*
%{_mandir}/man1/%{name}*
%{_mandir}/*/man1/%{name}*
%exclude %{_bindir}/%{name}-autostart
%exclude %{_mandir}/man1/%{name}-autostart*
%exclude %{_mandir}/*/man1/%{name}-autostart*
%exclude %{_mandir}/man1/%{name}-user-nic*
%exclude %{_mandir}/*/man1/%{name}-user-nic*
%{_datadir}/%{name}/%{name}.functions
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/*
%{abidir}/%{name}-*-option.list
%exclude %{abidir}/%{name}-autostart-option.list


%files libs
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/templates
%dir %{_datadir}/%{name}/config
%{_datadir}/%{name}/hooks
%{_datadir}/%{name}/%{name}-patch.py*
%{_datadir}/%{name}/selinux
%{_libdir}/liblxc.so.*
%{_libdir}/%{name}
%{_libexecdir}/%{name}
%{_sbindir}/init.%{name}
%{_bindir}/%{name}-autostart
%{_sharedstatedir}/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/default.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_mandir}/man1/%{name}-autostart*
%{_mandir}/*/man1/%{name}-autostart*
%{_mandir}/man1/%{name}-user-nic*
%{_mandir}/*/man1/%{name}-user-nic*
%{_mandir}/man5/%{name}*
%{_mandir}/man7/%{name}*
%{_mandir}/*/man5/%{name}*
%{_mandir}/*/man7/%{name}*
%{_mandir}/man8/pam_cgfs*
%{_mandir}/*/man8/pam_cgfs*
%license COPYING
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}@.service
%{_unitdir}/%{name}-net.service
%{_unitdir}/%{name}-monitord.service
%dir %{_localstatedir}/cache/%{name}
%{_libdir}/security/pam_cgfs.so
%dir %{abidir}
%{abidir}/liblxc.dump
%{abidir}/pam_cgfs.dump
%{abidir}/init.lxc-option.list
%{abidir}/lxc-autostart-option.list


%files templates
%{_datadir}/%{name}/templates/lxc-*
%{_datadir}/%{name}/config/*


%files devel
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/lxc
%{_libdir}/liblxc.so


%files doc
%license COPYING
%doc README.md


%changelog
* Sun Apr 09 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 5.0.2-1
- init from upstream
